@@ -240,6 +240,9 @@ class Worker(object):
             while True:
                 task = await self.pool.queue.get()
 
+                if task.n_try > 0:
+                    await asyncio.sleep(2)
+
                 try:
                     task.init_log()
                     await self.client.start()
@@ -252,7 +255,6 @@ class Worker(object):
                         try:
                             task.done_callback()
                         except Exception as exc:
-                            secho(f'Error executing return callback of task {self.name}: {str(exc)}', fg='red')
                             task.log(f'Error executing return callback of task {self.name}: {str(exc)}',
                                      self.client.host, err=True)
                 except Exception as exc:
@@ -260,9 +262,8 @@ class Worker(object):
                     if task.n_try < self.max_try:
                         await asyncio.sleep(1)
                         self.pool.queue.put_nowait(task)
-                        secho(f'Error executing task {self.name}: {str(exc)}, will retry ...', fg='red')
+                        task.log(f'Error executing task: {str(exc)}, will retry ...', self.client.host, err=True)
                     else:
-                        secho(f'Error executing task {self.name}: {str(exc)}', fg='red')
                         task.log(f'Error executing task {self.name}: {str(exc)}', self.client.host, err=True)
                     self.pool.queue.task_done()
                     self.running = False
@@ -334,7 +335,7 @@ class WorkerPool(object):
             name (str, optional): Name of the task. If not set it will be set by the worker pool
             output_file (str, optional): Optional filename to log output into.
         """
-        if self.env_file is not None:
+        if self.env_file:
             command = "sh -c '. %s; %s'" % (self.env_file, command)
         if name is None:
             name = f'T{len(self.tasks)}'
@@ -370,7 +371,7 @@ class WorkerPool(object):
 
         self.pbar.finish(dirty=len(self.tasks_error) > 0 or self.queue.qsize() > 0)
 
-    async def _monitor_queue(self, update_interval=2):
+    async def _monitor_queue(self, update_interval=1):
         try:
             while True:
                 await asyncio.sleep(update_interval)
@@ -388,11 +389,10 @@ class WorkerPool(object):
                                 if task.n_try < w.max_try - 1:
                                     print(task.n_try, w.max_try)
                                     task.log('Will retry ...', w.client.host, err=True)
+                                    task.n_try += 1
                                     self.queue.put_nowait(task)
                                     self.pbar.max_value += 1
-                                    task.n_try += 1
                                 await task.terminate()
-                                await asyncio.sleep(1)
 
                 if active_workers == 0:
                     print(f"No active workers, canceling all remaining tasks ...")
